@@ -89,17 +89,19 @@ test_that("run_benchmark: toolset", {
 })
 
 test_that("run_benchmark: toolset & testset", {
+  tool_names <- c("ROCR", "PRROC", "PerfMeas")
+  testset_names <- c("b10", "i10", "b100")
+
   tfunc <- function(use_sys_time) {
-    testset <- create_testset("bench", c("b10", "i10", "b100"))
-    toolset <- create_toolset(c("ROCR", "PRROC", "PerfMeas"))
+    testset <- create_testset("bench", testset_names)
+    toolset <- create_toolset(tool_names)
 
     res <- run_benchmark(testset, toolset, times = 1,
                          use_sys_time = use_sys_time)
 
-    expect_equal(as.character(res[[1]]$toolname),
-                 rep(c("ROCR", "PRROC", "PerfMeas"), 3))
-    expect_equal(as.character(res[[1]]$testset),
-                 rep(c("b10", "i10", "b100"), each = 3))
+
+    expect_true(all(as.character(res[[1]]$toolname) %in% tool_names))
+    expect_true(all(as.character(res[[1]]$testset) %in% testset_names))
   }
 
   use_sys_time <- .check_microbenchmark()
